package yrpg.bamp.basedata.common;

import kd.bos.util.StringUtils;
import org.apache.commons.lang.ArrayUtils;

public enum DBType {
    ORACLE(0, 1521, "oracle", "orcl"),
    POSTGRES(1, 5432, "postgresql", "postgres"),
    MYSQL(2, 3306, "mysql", ""),
    DM(3, 5236, "dameng", ""),
    GS(4, 1888, "gauss", ""),
    GS_100(5, 1888, "gauss100", ""),
    SQL_SERVER(6, 1433, "sqlserver", ""),
    XDB(7, 3306, "xdb", "");

    private int dbType;
    private int dbPort;
    private String dbName;
    private String dbInstance;
    private static final DBType[] NEED_INSTANCE_TYPES = new DBType[]{ORACLE, POSTGRES, SQL_SERVER, XDB};
    public static final DBType[] UNSUPPORTED_CREATE_TYPES = new DBType[]{ORACLE, POSTGRES, DM, GS, GS_100, SQL_SERVER, XDB};

    private DBType(int dbType, int dbPort, String dbName, String dbInstance) {
        this.dbType = dbType;
        this.dbPort = dbPort;
        this.dbName = dbName;
        this.dbInstance = dbInstance;
    }

    public int getDbType() {
        return this.dbType;
    }

    public int getDbPort() {
        return this.dbPort;
    }

    public String getDbName() {
        return this.dbName;
    }

    public String getDbInstance() {
        return this.dbInstance;
    }

    public static DBType getByDbName(String dbName) {
        DBType[] var1 = values();
        int var2 = var1.length;

        for (int var3 = 0; var3 < var2; ++var3) {
            DBType value = var1[var3];
            if (dbName.equalsIgnoreCase(value.dbName)) {
                return value;
            }
        }

        return MYSQL;
    }

    public static DBType getByDbType(int dbType) {
        DBType[] var1 = values();
        int var2 = var1.length;

        for (int var3 = 0; var3 < var2; ++var3) {
            DBType value = var1[var3];
            if (dbType == value.dbType) {
                return value;
            }
        }

        return MYSQL;
    }

    public boolean mustInputInstance() {
        return ArrayUtils.contains(NEED_INSTANCE_TYPES, this);
    }

    public String getDriver() {
        String driver;
        switch (this) {
            case ORACLE:
                driver = "oracle.jdbc.driver.OracleDriver";
                break;
            case POSTGRES:
            case GS:
                driver = "org.postgresql.Driver";
                break;
            case GS_100:
                driver = "com.huawei.gauss.jdbc.ZenithDriver";
                break;
            case SQL_SERVER:
                driver = "com.microsoft.sqlserver.jdbc.SQLServerDriver";
                break;
            case XDB:
                driver = "xdb.jdbc.driver.Driver";
                break;
            case DM:
                driver = "dm.jdbc.driver.DmDriver";
                break;
            default:
                driver = "com.mysql.cj.jdbc.Driver";
        }

        return driver;
    }

    public String getURL(String ip, int port, String instance) {
        if (StringUtils.isEmpty(instance)) {
            instance = this.dbInstance;
        }

        String url;
        switch (this) {
            case ORACLE:
                url = "jdbc:oracle:thin:@" + ip + ":" + port + "/" + instance;
//                url = "jdbc:oracle:thin:@" + ip + ":" + port + ":" + instance;
                break;
            case POSTGRES:
            case GS:
                url = "jdbc:postgresql://" + ip + ":" + port + "/" + instance;
                break;
            case GS_100:
                url = "jdbc:zenith:@" + ip + ":" + port;
                break;
            case SQL_SERVER:
                url = "jdbc:sqlserver://" + ip + ":" + port + ";DatabaseName=" + instance;
                break;
            case XDB:
                url = "jdbc:xdb:replication://" + ip + ":" + port + "/" + instance + "?serverTimezone=UTC&useSSL=false&useCursorFetch=true&useServerPrepStmts=true&cachePrepStmts=true&prepStmtCacheSize=1024&prepStmtCacheSqlLimit=4096";
                break;
            case DM:
                url = "jdbc:dm://" + ip + ":" + port + "/" + instance;
                break;
            default:
                url = "jdbc:mysql://" + ip + ":" + port + "/" + instance;
        }

        return url;
    }
}
